make_lid = false;
make_case = false;

$fn = 17;
mks_gen_l_dim_x = 110;
mks_gen_l_dim_y = 84;

mks_gen_l_x_hole_spacing = 102;
mks_gen_l_y_hole_spacing = 76;

base_thickness = 1.5;
wall_thickness = 2;

case_buffer_x = 10;
case_buffer_y = 8;

tl_smoother_depth = 29.5;
tl_smoother_width = 39.9;

lower_case_x = mks_gen_l_dim_y + case_buffer_x + tl_smoother_width + 4;
lower_case_y = mks_gen_l_dim_x + case_buffer_y + 10;

case_height = 39 + base_thickness;

vent_hole_dia = 10;

m4_screw_radius = 4.826/2;
m4_hole_radius = m4_screw_radius * 1.20; 

back_slot_height = case_height - 13;
m3_screw_radius = (7.5/64.0 * 25.4)/2;
lid_mount_height = 4;
lid_mount_dim = m3_screw_radius *4.5;

rail_dim = 20;
rail_tab_thickness = 4;
rail_tab_hole_radius = 5.75/2.0;
mounting_tab_dim = rail_dim - 7;

top_tab_offset = lower_case_x - mounting_tab_dim - 52.5;

fan_screw_dia = 5;
fan_screw_hole_size = fan_screw_dia/2 * 1.15;
fan_dia = 80;
fan_hole_spacing = 71.5;
fan_buffer = (80 - fan_hole_spacing - 4.5)/2;

tl_smoother_mounting_hole_radius = ((10/64.0) * 25.4)/2;

tl_smoother_mounting_hole_disp = (5/64.0) * 25.4 + tl_smoother_mounting_hole_radius;
tl_smoother_width_hole_spacing = 36 - tl_smoother_mounting_hole_radius * 2;
tl_smoother_depth_hole_spacing = 26 - tl_smoother_mounting_hole_radius * 2;
no6_screw_thread_radius = (9/64.0 * 25.4)/2;

tl_smoother_mounting_post_height = 4;

// corner posts
corner_post_radius = 5;
corner_post_inset = 0.8;
corner_post_height = corner_post_radius  * (2/3);

module tl_smoother_mounting_post(){
  translate([no6_screw_thread_radius + 2,no6_screw_thread_radius + 2,0]){
      difference(){
        cylinder ( r = no6_screw_thread_radius + 2, h = tl_smoother_mounting_post_height);
        cylinder ( r = no6_screw_thread_radius * 0.92, h = tl_smoother_mounting_post_height * 9, $fn = 44);      
      }
    }
}

module tl_smoother_mount(){
  tl_smoother_mounting_post();
  translate([tl_smoother_width_hole_spacing,0,0]){
    tl_smoother_mounting_post();
  }
  translate([tl_smoother_width_hole_spacing,tl_smoother_depth_hole_spacing,0]){
    tl_smoother_mounting_post();
  }
  translate([0,tl_smoother_depth_hole_spacing,0]){
    tl_smoother_mounting_post();
  }
}
tl_smoother_spacing = 6;

module standoff(inner_radius, outer_radius, h){
  difference(){
    color("red") cylinder(r = outer_radius, h = h);
    cylinder(r = inner_radius, h = h +2);
  }
}

standoff_height = 3.5;
module mounting_standoffs(spacing_x, spacing_y, hole_dia){
  standoff_radius_factor = 2.0;
  standoff(hole_dia/2, hole_dia/2 * standoff_radius_factor, standoff_height);
  translate([spacing_x,0,0]){
    standoff(hole_dia/2, hole_dia/2 * standoff_radius_factor, standoff_height);
  }
  
  translate([spacing_x,spacing_y,0]){
    standoff(hole_dia/2, hole_dia/2 * standoff_radius_factor, standoff_height);
  }
  
  translate([0,spacing_y,0]){
    standoff(hole_dia/2, hole_dia/2 * standoff_radius_factor, standoff_height);
  }
}


// the lid
if(make_lid){
translate([0,0,case_height + 10]){
  difference(){
   color("blue") cube([lower_case_x + wall_thickness, lower_case_y + wall_thickness, base_thickness]);
    union(){
      translate([0,0,-2]){
        // Begin mounting holes
        translate([wall_thickness + lid_mount_dim/2,wall_thickness + lid_mount_dim/2,0]){
          cylinder(r = 1.15 * m3_screw_radius, h = base_thickness * 4);
        }        
        translate([wall_thickness + lid_mount_dim/2,lower_case_y - (lid_mount_dim/2),0]){
          cylinder(r = 1.15 *m3_screw_radius, h = base_thickness * 4);
        }
        
        translate([lower_case_x - lid_mount_dim/2,lower_case_y - (lid_mount_dim/2),0]){
          cylinder(r = 1.15 *m3_screw_radius, h = base_thickness * 4);
        }        
        translate([lower_case_x - lid_mount_dim/2,wall_thickness + (lid_mount_dim/2),0]){
          cylinder(r = 1.15 *m3_screw_radius, h = base_thickness * 4);
        }
        // End mounting holes
      }
      
        // fan hole 
      translate([lower_case_x - fan_dia - 10 ,(lower_case_y - fan_dia)/2 + 6,-1]){
        translate([(fan_dia+0.5)/2,(fan_dia+0/5)/2,0]){
          cylinder(r=(fan_dia+0.5)/2, h = base_thickness * 2, $fn = 25);
        }
        
        translate([fan_screw_hole_size + fan_buffer,fan_screw_hole_size + fan_buffer,0]){
          cylinder(r = fan_screw_hole_size, h = base_thickness * 2);
        }        
        translate([fan_screw_hole_size + fan_buffer + fan_hole_spacing,fan_screw_hole_size + fan_buffer,0]){
          cylinder(r = fan_screw_hole_size, h = base_thickness * 2);
        }        
        translate([fan_screw_hole_size + fan_buffer + fan_hole_spacing,fan_screw_hole_size + fan_buffer + fan_hole_spacing,0]){
          cylinder(r = fan_screw_hole_size, h = base_thickness * 2);
        }        
        translate([fan_screw_hole_size + fan_buffer,fan_screw_hole_size + fan_buffer + fan_hole_spacing,0]){
          cylinder(r = fan_screw_hole_size, h = base_thickness * 2);
        }        

        translate([fan_dia * 0.75, fan_dia + 4, 0]){
          cube([8.1,6.6,base_thickness *3]);
        }
      }
    }
  }
}
// end of the lid
}


module rounded_rectangle(x,y,z,rounding_radius){
  minkowski(){
    translate([rounding_radius,rounding_radius,0]){
      cube([x - (rounding_radius*2),y - (rounding_radius*2),z]);
    }
    cylinder(r=rounding_radius, h=1);
  };
}

module half_rounded_rectangle(x,y,z,rounding_radius){
  union(){
    translate([0,y/2,0]){
       cube([x,y/2 ,z]);
    }
    difference(){      
      minkowski(){
        translate([rounding_radius,rounding_radius,0]){
          cube([x - (rounding_radius*2),y - (rounding_radius*2),z -1]);
        }
        cylinder(r=rounding_radius, h=1);
      };
      translate([-2,y/2 ,-2]){
        cube([x+4,y/2 ,z+4]);
      }
    }
  }
}

  
  module corner_post() {
  cylinder(r1 = corner_post_radius, h = corner_post_height, r2 = corner_post_radius/2, $fn = 40);
}


slot_rounding_radius = 4.5;
zip_tie_width = 5.5;
zip_tie_height = 2;
zip_tie_tab_dim = 13;
zip_tie_tab_rounding_radius = 1.5;

module zip_tie_rack(){
  difference(){
      translate([zip_tie_tab_rounding_radius,0,0]){
        minkowski(){
          cube([wall_thickness - zip_tie_tab_rounding_radius,zip_tie_tab_dim,case_height -8]);
          cylinder(r = zip_tie_tab_rounding_radius, h =1);
        }
      }
      translate([-1*wall_thickness,zip_tie_tab_dim*(2/3.0) - zip_tie_width/2,base_thickness + rail_tab_thickness - 2]){
        union(){
          for(i=[0:4]){
            translate([0,0,i*(zip_tie_height*2 + 1.75)]){
              cube([wall_thickness*3,zip_tie_width, zip_tie_height * 2]);
            }
          }
        }
      }
    }
}



module lid_mount(){
  
  difference(){
    color("blue") cube([lid_mount_dim, lid_mount_dim, lid_mount_height]);
    translate([lid_mount_dim/2, lid_mount_dim/2, -1]){
      cylinder(r = m3_screw_radius, h = lid_mount_height + 5);
    }
  }
  
}

if (make_case){
// main case
union(){
  // the base itself
  cube([lower_case_x, lower_case_y, base_thickness]);
  
  // The TL smoother mounts
  color("red") translate([mks_gen_l_dim_y + case_buffer_x + 2,case_buffer_y,base_thickness - 0.1]){
    tl_smoother_mount();

    translate([0,tl_smoother_depth + tl_smoother_spacing,0]){
      tl_smoother_mount();
    }
    translate([0,2*(tl_smoother_depth + tl_smoother_spacing),0]){
      tl_smoother_mount();
    }
  }

  // The corner posts
  //origin
  translate([corner_post_inset, corner_post_inset,0]){
    corner_post();
  }
  //bottom right
  translate([lower_case_x+ wall_thickness - corner_post_inset,corner_post_inset,0]){
    corner_post();
  }
  // top right
  translate([lower_case_x+ wall_thickness- corner_post_inset,lower_case_y + wall_thickness- corner_post_inset,0]){
    corner_post();
  }
  // top left
  translate([corner_post_inset,lower_case_y + wall_thickness- corner_post_inset,0]){
    cylinder(r1 = corner_post_radius, h = corner_post_height, r2 = corner_post_radius/2, $fn = 40);
  }
  
  // shift to space off the MKS Gen L
  translate([case_buffer_x, case_buffer_y + ( mks_gen_l_dim_x - mks_gen_l_x_hole_spacing)/2.0,base_thickness]){
    // mounting holes for the MKS Gen L
    mounting_standoffs(mks_gen_l_y_hole_spacing, mks_gen_l_x_hole_spacing, 2.981);
    
  }
  
  translate([0,0,0]){
    difference(){        
      translate([0,-1 * mounting_tab_dim,,0]){
        half_rounded_rectangle(wall_thickness + mounting_tab_dim, mounting_tab_dim, rail_tab_thickness, 2);        
      }
      translate([wall_thickness + rail_tab_hole_radius * 2.5, rail_tab_hole_radius * -2.5,-2]){
        cylinder(h = rail_tab_thickness  *2 , r = rail_tab_hole_radius); 
      }
    }
  }
  translate([lower_case_x - mounting_tab_dim - wall_thickness,0,0]){
    difference(){        
      translate([wall_thickness,-1 * mounting_tab_dim,,0]){
        half_rounded_rectangle(wall_thickness + mounting_tab_dim, mounting_tab_dim, rail_tab_thickness, 2);        
      }
      translate([(wall_thickness + mounting_tab_dim) - rail_tab_hole_radius * 2.5, rail_tab_hole_radius * -2.5,-2]){
        cylinder(h = rail_tab_thickness  *2 , r = rail_tab_hole_radius); 
      }
    }
  }
  
  // top tab
  translate([top_tab_offset - wall_thickness,wall_thickness + lower_case_y,0]){
    difference(){      
      translate([wall_thickness + mounting_tab_dim,mounting_tab_dim,0]){
      rotate([0,0,180]){
        half_rounded_rectangle(wall_thickness + mounting_tab_dim, mounting_tab_dim, rail_tab_thickness, 2); 
        
      }
      translate([-1,-1 * mounting_tab_dim,rail_tab_thickness]){
        rotate([0,-90,0]){    
          linear_extrude(height = wall_thickness){
            polygon([[0,0],[mounting_tab_dim * 0.92 ,0],[0,mounting_tab_dim * 0.92]]);
          }
        }
      }
    }
      
      translate([mounting_tab_dim/2, (mounting_tab_dim/2),-2]){
        cylinder(h = rail_tab_thickness  *2 , r = rail_tab_hole_radius); 
      }
    }
  }
  
  
  translate([1,0,rail_tab_thickness]){
    rotate([180,-90,0]){
      linear_extrude(height = wall_thickness){
        polygon([[0,0],[mounting_tab_dim * 0.92 ,0],[0,mounting_tab_dim * 0.92]]);
      }
    }
  }
  
  
  translate([lower_case_x - 1,0,rail_tab_thickness]){
    rotate([180,-90,0]){    
      linear_extrude(height = wall_thickness){
        polygon([[0,0],[mounting_tab_dim * 0.92 ,0],[0,mounting_tab_dim * 0.92]]);
      }
    }
  }
  
  

}
//wall
union(){
  cube([lower_case_x, wall_thickness, case_height]);   
}

//wall
translate([lower_case_x,0,0]){
  difference(){
    cube([wall_thickness, lower_case_y, case_height]);
    translate([-1, 10 + base_thickness + vent_hole_dia/2, 5+ base_thickness + vent_hole_dia]){
      union(){
        for(i=[0:7]){
          translate([0,1.33 * vent_hole_dia * i,-1 * 0.5 * i]){
            rotate([0,90,0]){
             cylinder(r = vent_hole_dia/2, h = wall_thickness * 3);
            }
          }
        }
      }
    }
  }
}



motor_power_lead_slot_width = 16;
//wall
translate([0,lower_case_y,0]){
  difference(){
    cube([lower_case_x + wall_thickness, wall_thickness, case_height]);
    
    translate([case_buffer_x,wall_thickness *-2,rail_tab_thickness]){
      minkowski(){
        translate([0, slot_rounding_radius, slot_rounding_radius]){
          cube([mks_gen_l_y_hole_spacing - 9 - slot_rounding_radius*2,wall_thickness * 2, back_slot_height - slot_rounding_radius * 2 ]);
        }
        rotate([90,0,0]){
          cylinder(r = slot_rounding_radius, h =1);
        }
      }
    }
     translate([lower_case_y - 3,wall_thickness *-2,rail_tab_thickness]){
      minkowski(){
        translate([0, slot_rounding_radius, slot_rounding_radius]){
          cube([motor_power_lead_slot_width - slot_rounding_radius*2,wall_thickness * 2, back_slot_height - slot_rounding_radius * 2 ]);
        }
        rotate([90,0,0]){
          cylinder(r = slot_rounding_radius, h =1);
        }
      }
    }
  }
  
  //top zip tie mount
  
  translate([wall_thickness - 1.2,wall_thickness,0]){
    zip_tie_rack();
  }
  
  translate([lower_case_y - motor_power_lead_slot_width + 4,wall_thickness,0]){
    zip_tie_rack();
  }
}

x_slot_gap = 18;
x_slot_1 = 53;
x_slot_2 = mks_gen_l_dim_x  - x_slot_1 - x_slot_gap -3.5;


//wall
difference(){
  union(){
    cube([wall_thickness, lower_case_y, case_height]);    
  }
  translate([-2, case_buffer_y, base_thickness + (standoff_height - 0.5)]){
    
    minkowski(){
      translate([0, slot_rounding_radius, slot_rounding_radius]){
        cube([wall_thickness + 4, x_slot_1 - slot_rounding_radius*2, back_slot_height - slot_rounding_radius *2]);
      }
       rotate([0,90,0]){
          cylinder(r = slot_rounding_radius, h =1);
        }
    }
    
    
    translate([0,x_slot_1 + x_slot_gap,0]){

      minkowski(){ 
          translate([0, slot_rounding_radius, slot_rounding_radius]){
            cube([wall_thickness + 4, x_slot_2 - slot_rounding_radius*2, back_slot_height - slot_rounding_radius * 2]);
          }
          rotate([0,90,0]){
            cylinder(r = slot_rounding_radius, h =1);
          }
      };
    
    }
  }
}




// mounting points for lid
translate([wall_thickness, wall_thickness, case_height - lid_mount_height]){  
  lid_mount();
}
translate([lower_case_x - lid_mount_dim, wall_thickness, case_height - lid_mount_height]){
  lid_mount();
}
translate([lower_case_x - lid_mount_dim, lower_case_y - lid_mount_dim, case_height - lid_mount_height]){
  lid_mount();
}
translate([wall_thickness, lower_case_y - lid_mount_dim, case_height - lid_mount_height]){
  lid_mount();
}

}
